# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["RouteStepCompletionMode"]

RouteStepCompletionMode: TypeAlias = Literal["`manual`", "`geofence`", "`geofence_manual_fallback`"]
