# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .rich_group_response import RichGroupResponse

__all__ = ["RestrictionListByBboxResponse"]

RestrictionListByBboxResponse: TypeAlias = List[RichGroupResponse]
